S3StorageProvider

Struct S3StorageProvider 

pub struct S3StorageProvider { /* private fields */ }
Storage client for working with S3-compatible APIs.

See the module-level docs for more information.

Implementations

Source

impl S3StorageProvider

pub fn new( bucket_name: &str, endpoint_url: &str, region: &str, access_key: &str, secret_key: &str, ) -> Self

Construct a new client, returning an error if the information could not be used to communicate with a valid bucket.